@@ -1054,7 +1054,7 @@ class WordToken(models.Model):
                                 if x['F1(Hz)'] != '--undefined--' and x['F2(Hz)'] != '--undefined--']
             to_out = [ {'time(s)':x['time(s)'],
                             'F1(Hz)':x['F1(Hz)'],
-                            'F2(Hz)':x['F2(Hz)'}.update({k:outline[k] for k in outline
+                            'F2(Hz)':x['F2(Hz)']}.update({k:outline[k] for k in outline
                                                             if k != 'formants' and k in wanted_fields})
                             for x in outline['formants']]
         else:
